==> lhcsmapi-1.2.19.tar.gz: lhcsmapi-1.2.19/lhcsmapi/gui/qh/QuenchHeaterBrowser.py <==
import ipywidgets as widgets
import os
from ipywidgets import Button, Layout, HBox, VBox, Box
from ...metadata.SignalMetadata import SignalMetadata
from ...metadata.MappingMetadata import MappingMetadata
from ...metadata.Metadata import Metadata
from ...dbsignal.Signal import Signal
from ...Time import Time
import pandas as pd
import matplotlib.pyplot as plt
from IPython.display import clear_output

query_output = []
index_output = 0

def show():
    selected_path = os.path.dirname(__file__)
    full_path = os.path.join(str(selected_path), 'RB_QH_2013_1_1-6-0-0_Timestamp_features.csv')
    filtered_data_small = pd.read_csv(full_path)
    filtered_data_small = filtered_data_small.drop(columns=['Unnamed: 0'])

    circuit_names = SignalMetadata.get_circuit_names('RB')
    cells_per_circuit = MappingMetadata.get_cells_for_circuit_names('RB', 'RB.A12')

    class State(object):
        def __init__(self):
            self.cir = sel_cir.options[sel_cir.index]
            self.cirname = list(selmul_cirname.value)
            self.cell = sel_cell.value

    txt_start = widgets.Text(
        value='2014-01-01 00:00:00',
        placeholder='YYYY-MM-DD HH:MM:SS',
        description='Start time:',
        disabled=False
    )

    def on_value_change_txt_start(change):
        update_discharges()

    txt_start.on_submit(on_value_change_txt_start)

    txt_end = widgets.Text(
        value='2018-12-31 00:00:00',
        placeholder='YYYY-MM-DD HH:MM:SS',
        description='End time:',
        disabled=False
    )

    def on_value_change_txt_end(change):
        update_discharges()

    txt_end.on_submit(on_value_change_txt_end)

    box_0 = Box(children=[txt_start, txt_end])

    # Circuit
    sel_cir = widgets.Select(
        options=['RB'],
        description='Type',
        layout=Layout(display="flex", flex_flow='column', width='15%')
    )
    # Cirname
    selmul_cirname = widgets.SelectMultiple(
        options=circuit_names,
        description='Circuit Name',
        layout=Layout(display="flex", flex_flow='column', width='15%')
    )

    def on_value_change_sel_cirname(change):
        with sel_cell.hold_trait_notifications():
            sel_cell.options = MappingMetadata.get_cells_for_circuit_names(State().cir, State().cirname)

    selmul_cirname.observe(on_value_change_sel_cirname, names='value')

    # Cell
    sel_cell = widgets.Select(
        options=cells_per_circuit,
        description='Cell',
        layout=Layout(display="flex", flex_flow='column', width='20%')
    )

    def get_discharges():
        are_cells_selected = filtered_data_small['magnet'] == State().cell
        cell_data = filtered_data_small[are_cells_selected].reset_index().drop(columns=['index'])
        mask = (cell_data['date'] > txt_start.value) & (cell_data['date'] < txt_end.value)
        return cell_data.loc[mask]

    layout_hidden = widgets.Layout(width='25%', visibility='hidden')
    layout_visible = widgets.Layout(width='25%', visibility='visible')

    slider = widgets.IntSlider(
        value=0,
        min=0,
        step=1,
        description='Select Cell:',
        disabled=False,
        continuous_update=False,
        orientation='horizontal',
        readout=True,
        readout_format='d',
        layout=layout_hidden
    )

    lbl_querry = widgets.Label(value="")
    progress_querry = widgets.IntProgress(value=0, min=0, step=1, bar_style='success', orientation='horizontal',
                                          layout=Layout(width='20%'))

    def on_value_change(change):
        k = slider.value
        circuit_type = State().cir
        df = query_output[k]

        with out:
            clear_output(True)
            fig, ax = plt.subplots(1, 2, figsize=(10, 5))
            df.filter(regex=("U_HDS_\d{1}")).plot(ax=ax[0]).set(xlabel="[s]", ylabel="[V]")
            if circuit_type == "RB":
                df.filter(regex=("I_HDS_\d{1}")).plot(ax=ax[1]).set(xlabel="[s]", ylabel="[A]")
            display(get_discharges())

    slider.observe(on_value_change, names='value')

    out = widgets.Output()

    def on_value_change_sel_cell(change):
        update_discharges()

    def update_discharges():
        slider.layout = layout_hidden
        lbl_querry.value = 'Press [Query] to load selected signals'
        progress_querry.value = 0
        progress_querry.description = ''
        with out:
            clear_output(True)
            display(get_discharges())

    update_discharges()

    sel_cell.observe(on_value_change_sel_cell, names='value')

    btn_querry = widgets.Button(description="Query", layout=Layout(width='15%'))

    def on_btn_querry_clicked(b):
        global query_output
        if len(query_output) > 0:
            query_output = []

        # from new SignalMetadata
        circuit_type = 'RB'
        system_type = 'QPS'
        component = 'QH'

        magnet_type_to_signal_metadata = Metadata.getMetadata(circuit_type, system_type)
        qps_metadata = magnet_type_to_signal_metadata[system_type]
        system = qps_metadata[component]["PM"]['system']
        class_name = qps_metadata[component]["PM"]['className']
        U_HDS = magnet_type_to_signal_metadata[system_type][component]["PM"]["U_HDS"]
        I_HDS = magnet_type_to_signal_metadata[system_type][component]["PM"]["I_HDS"]

        full_data_given_magnet = get_discharges()
        progress_querry.max = len(full_data_given_magnet)
        slider.max = len(full_data_given_magnet)
        i = 0
        for index, row in full_data_given_magnet.iterrows():
            timestamp = row['timestamp']
            magnet = row['magnet']

            progress_querry.value = i + 1
            progress_querry.description = '{}/{}'.format(i + 1, len(full_data_given_magnet))
            lbl_querry.value = "Querying signal {} at {} ({}), please wait...".format(magnet, int(timestamp),
                                                                                      Time.to_string(
                                                                                          int(timestamp)))

            qh_discharge = Signal()
            for signal_name in U_HDS + I_HDS:
                qh_discharge.read('pm', append=True, system=system, className=class_name, source=magnet,
                                 signal=signal_name, eventTime=int(timestamp))

            query_output.append(qh_discharge.get_synchronized_time_df())
            i += 1

        lbl_querry.value = "Query completed.".format(magnet, int(timestamp), Time.to_string(int(timestamp)))
        slider.layout = layout_visible

    btn_querry.on_click(on_btn_querry_clicked)

    box_1 = Box(children=[sel_cir, selmul_cirname, sel_cell])

    btn_save = widgets.Button(description="Save to csv", layout=Layout(width='15%'))

    def on_btn_save_clicked(b):
        global query_output
        global index_output
        progress_querry.max = len(query_output)
        lbl_querry.value = 'Saving to csv.'
        for i in range(len(query_output)):
            file_name = '{}_{}_{}.csv'.format(index_output, State().cir, State().cell)

            progress_querry.value = i + 1
            progress_querry.description = '{}/{}'.format(i + 1, len(query_output))
            index_output += 1
            query_output[i].to_csv(file_name)

    btn_save.on_click(on_btn_save_clicked)

    box_2 = Box(children=[btn_querry, btn_save, lbl_querry, progress_querry])

    box_3 = Box(children=[slider])

    return VBox([box_0, box_1, box_2, box_3]), out

==> lhcsmapi-1.2.111.tar.gz: lhcsmapi-1.2.111/lhcsmapi/gui/qh/QuenchHeaterBrowser.py <==
import ipywidgets as widgets
import os
from ipywidgets import Button, Layout, HBox, VBox, Box
from lhcsmapi.metadata.SignalMetadata import SignalMetadata
from lhcsmapi.metadata.MappingMetadata import MappingMetadata
from lhcsmapi.dbsignal.Signal import Signal
from lhcsmapi.Time import Time
import pandas as pd
import matplotlib.pyplot as plt
from IPython.display import clear_output

query_output = []
index_output = 0

def show():
    selected_path = os.path.dirname(__file__)
    full_path = os.path.join(str(selected_path), 'RB_QH_2013_1_1-6-0-0_Timestamp_features.csv')
    filtered_data_small = pd.read_csv(full_path)
    filtered_data_small = filtered_data_small.drop(columns=['Unnamed: 0'])

    circuit_names = SignalMetadata.get_circuit_names('RB')
    cells_per_circuit = MappingMetadata.get_cells_for_circuit_names('RB', 'RB.A12')

    class State(object):
        def __init__(self):
            self.cir = sel_cir.options[sel_cir.index]
            self.cirname = list(selmul_cirname.value)
            self.cell = sel_cell.value

    txt_start = widgets.Text(
        value='2014-01-01 00:00:00',
        placeholder='YYYY-MM-DD HH:MM:SS',
        description='Start time:',
        disabled=False
    )

    def on_value_change_txt_start(change):
        update_discharges()

    txt_start.on_submit(on_value_change_txt_start)

    txt_end = widgets.Text(
        value='2018-12-31 00:00:00',
        placeholder='YYYY-MM-DD HH:MM:SS',
        description='End time:',
        disabled=False
    )

    def on_value_change_txt_end(change):
        update_discharges()

    txt_end.on_submit(on_value_change_txt_end)

    box_0 = Box(children=[txt_start, txt_end])

    # Circuit
    sel_cir = widgets.Select(
        options=['RB'],
        description='Type',
        layout=Layout(display="flex", flex_flow='column', width='15%')
    )
    # Cirname
    selmul_cirname = widgets.SelectMultiple(
        options=circuit_names,
        description='Circuit Name',
        layout=Layout(display="flex", flex_flow='column', width='15%')
    )

    def on_value_change_sel_cirname(change):
        with sel_cell.hold_trait_notifications():
            sel_cell.options = MappingMetadata.get_cells_for_circuit_names(State().cir, State().cirname)

    selmul_cirname.observe(on_value_change_sel_cirname, names='value')

    # Cell
    sel_cell = widgets.Select(
        options=cells_per_circuit,
        description='Cell',
        layout=Layout(display="flex", flex_flow='column', width='20%')
    )

    def get_discharges():
        are_cells_selected = filtered_data_small['magnet'] == State().cell
        cell_data = filtered_data_small[are_cells_selected].reset_index().drop(columns=['index'])
        mask = (cell_data['date'] > txt_start.value) & (cell_data['date'] < txt_end.value)
        return cell_data.loc[mask]

    layout_hidden = widgets.Layout(width='25%', visibility='hidden')
    layout_visible = widgets.Layout(width='25%', visibility='visible')

    slider = widgets.IntSlider(
        value=0,
        min=0,
        step=1,
        description='Select Cell:',
        disabled=False,
        continuous_update=False,
        orientation='horizontal',
        readout=True,
        readout_format='d',
        layout=layout_hidden
    )

    lbl_querry = widgets.Label(value="")
    progress_querry = widgets.IntProgress(value=0, min=0, step=1, bar_style='success', orientation='horizontal',
                                          layout=Layout(width='20%'))

    def on_value_change(change):
        k = slider.value
        circuit_type = State().cir
        df = query_output[k]

        with out:
            clear_output(True)
            fig, ax = plt.subplots(1, 2, figsize=(10, 5))
            df.filter(regex=("U_HDS_\d{1}")).plot(ax=ax[0]).set(xlabel="[s]", ylabel="[V]")
            if circuit_type == "RB":
                df.filter(regex=("I_HDS_\d{1}")).plot(ax=ax[1]).set(xlabel="[s]", ylabel="[A]")
            display(get_discharges())

    slider.observe(on_value_change, names='value')

    out = widgets.Output()

    def on_value_change_sel_cell(change):
        update_discharges()

    def update_discharges():
        slider.layout = layout_hidden
        lbl_querry.value = 'Press [Query] to load selected signals'
        progress_querry.value = 0
        progress_querry.description = ''
        with out:
            clear_output(True)
            display(get_discharges())

    update_discharges()

    sel_cell.observe(on_value_change_sel_cell, names='value')

    btn_querry = widgets.Button(description="Query", layout=Layout(width='15%'))

    def on_btn_querry_clicked(b):
        global query_output
        if len(query_output) > 0:
            query_output = []

        # from new SignalMetadata
        circuit_type = 'RB'
        system_type = 'QPS'
        component = 'QH'

        magnet_type_to_signal_metadata = Metadata.getMetadata(circuit_type, system_type)
        qps_metadata = magnet_type_to_signal_metadata[system_type]
        system = qps_metadata[component]["PM"]['system']
        class_name = qps_metadata[component]["PM"]['className']
        U_HDS = magnet_type_to_signal_metadata[system_type][component]["PM"]["U_HDS"]
        I_HDS = magnet_type_to_signal_metadata[system_type][component]["PM"]["I_HDS"]

        full_data_given_magnet = get_discharges()
        progress_querry.max = len(full_data_given_magnet)
        slider.max = len(full_data_given_magnet)
        i = 0
        for index, row in full_data_given_magnet.iterrows():
            timestamp = row['timestamp']
            magnet = row['magnet']

            progress_querry.value = i + 1
            progress_querry.description = '{}/{}'.format(i + 1, len(full_data_given_magnet))
            lbl_querry.value = "Querying signal {} at {} ({}), please wait...".format(magnet, int(timestamp),
                                                                                      Time.to_string(
                                                                                          int(timestamp)))

            qh_discharge = Signal()
            for signal_name in U_HDS + I_HDS:
                qh_discharge.read('pm', append=True, system=system, className=class_name, source=magnet,
                                 signal=signal_name, eventTime=int(timestamp))

            query_output.append(qh_discharge.get_synchronized_time_df())
            i += 1

        lbl_querry.value = "Query completed.".format(magnet, int(timestamp), Time.to_string(int(timestamp)))
        slider.layout = layout_visible

    btn_querry.on_click(on_btn_querry_clicked)

    box_1 = Box(children=[sel_cir, selmul_cirname, sel_cell])

    btn_save = widgets.Button(description="Save to csv", layout=Layout(width='15%'))

    def on_btn_save_clicked(b):
        global query_output
        global index_output
        progress_querry.max = len(query_output)
        lbl_querry.value = 'Saving to csv.'
        for i in range(len(query_output)):
            file_name = '{}_{}_{}.csv'.format(index_output, State().cir, State().cell)

            progress_querry.value = i + 1
            progress_querry.description = '{}/{}'.format(i + 1, len(query_output))
            index_output += 1
            query_output[i].to_csv(file_name)

    btn_save.on_click(on_btn_save_clicked)

    box_2 = Box(children=[btn_querry, btn_save, lbl_querry, progress_querry])

    box_3 = Box(children=[slider])

    return VBox([box_0, box_1, box_2, box_3]), out
